==> banking-branch_14.8.0.0.0-Plus1.zip: banking-branch_14.8.0.0.0-Plus1_20250419/content/banking-branch/14.8.0.0.0/relno/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-9CBAE136-83F9-401E-9748-BA17CD98DD75"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Release Notes",
                    "href":"release-notes1.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Release Highlights",
                            "href":"release-highlights.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> Release Enhancements",
                            "href":"release-enhancements.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.2.1 </span> Enhancements in Oracle Banking Party",
                                    "href":"enhancements-party-services.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.2 </span> Enhancements in Retail Account Servicing",
                                    "href":"enhancements-retail-account-servicing.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.3 </span> Enhancements in Retail Lending Services",
                                    "href":"enhancements-loan-servicing.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.4 </span> Enhancements in Retail Deposit Servicing",
                                    "href":"enhancements-retail-deposit-servicing.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.5 </span> Enhancements in Teller",
                                    "href":"enhancements-teller.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Components of the Software",
                    "href":"components-software.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">2.1 </span> Documents Accompanying the Software",
                            "href":"documents-accompanying-software.html"
                        },
                        {
                            "title":"<span class=\"secnum\">2.2 </span> Software Components",
                            "href":"software-components.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Environment Details",
                    "href":"environment-details.html"
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Third-Party Software",
                    "href":"third-party-software.html"
                },
                {
                    "title":"Index",
                    "href":"book-index.html"
                }
            ]
        }
    ]
});

==> banking-branch_14.8.1.0.0-Plus1.zip: banking-branch_14.8.1.0.0-Plus1_20251105/content/banking-branch/14.8.1.0.0/relno/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-9CBAE136-83F9-401E-9748-BA17CD98DD75"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Release Notes",
                    "href":"release-notes.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">1.1 </span> Release Highlights",
                            "href":"release-highlights.html"
                        },
                        {
                            "title":"<span class=\"secnum\">1.2 </span> Release Enhancements",
                            "href":"release-enhancements.html",
                            "topics":[
                                {
                                    "title":"<span class=\"secnum\">1.2.1 </span> Enhancements in Oracle Banking Party",
                                    "href":"enhancements-party-services.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.2 </span> Enhancements in Retail Account Servicing",
                                    "href":"enhancements-retail-account-servicing.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.3 </span> Enhancements in Retail Lending Services",
                                    "href":"enhancements-loan-servicing.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.4 </span> Enhancements in Retail Deposit Servicing",
                                    "href":"enhancements-retail-deposit-servicing.html"
                                },
                                {
                                    "title":"<span class=\"secnum\">1.2.5 </span> Enhancements in Teller",
                                    "href":"enhancements-teller.html"
                                }
                            ]
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">2 </span> Technical Changes",
                    "href":"technical-changes.html"
                },
                {
                    "title":"<span class=\"secnum\">3 </span> Components of the Software",
                    "href":"components-software.html",
                    "topics":[
                        {
                            "title":"<span class=\"secnum\">3.1 </span> Documents Accompanying the Software",
                            "href":"documents-accompanying-software.html"
                        },
                        {
                            "title":"<span class=\"secnum\">3.2 </span> Software Components",
                            "href":"software-components.html"
                        }
                    ]
                },
                {
                    "title":"<span class=\"secnum\">4 </span> Environment Details",
                    "href":"environment-details.html"
                },
                {
                    "title":"<span class=\"secnum\">5 </span> Third-Party Software",
                    "href":"third-party-software.html"
                },
                {
                    "title":"Index",
                    "href":"book-index.html"
                }
            ]
        }
    ]
});
